@@ -66,6 +66,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 	type args struct {
 		path []int
 		tag  string
+		cmd  int
 	}
 
 	tests := []struct {
@@ -80,7 +81,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, NodeType},
+			args{[]int{}, NodeType, EmberGetDirCommand},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x6a, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -93,7 +94,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, QualifiedNodeType},
+			args{[]int{}, QualifiedNodeType, EmberGetDirCommand},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x6a, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -106,7 +107,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, ParameterType},
+			args{[]int{}, ParameterType, EmberGetDirCommand},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x69, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -119,7 +120,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, QualifiedParameterType},
+			args{[]int{}, QualifiedParameterType, EmberGetDirCommand},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x69, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -132,7 +133,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, FunctionType},
+			args{[]int{}, FunctionType, EmberGetDirCommand},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x74, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -145,7 +146,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{0x00}),
 			},
-			args{[]int{}, FunctionType},
+			args{[]int{}, FunctionType, EmberGetDirCommand},
 			[]byte{
 				0x00, 0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x74, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00, 0x00,
@@ -153,12 +154,25 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			},
 			false,
 		},
+		{
+			"+unsubscribe",
+			fields{
+				bytes.NewBuffer([]byte{}),
+			},
+			args{[]int{}, ParameterType, EmberGetUnsubscribeCommand},
+			[]byte{
+				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x69, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
+				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+				0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+			},
+			false,
+		},
 		{
 			"-invalidType",
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, "foobar"},
+			args{[]int{}, "foobar", EmberGetDirCommand},
 			[]byte{0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
 			true,
 		},
@@ -172,7 +186,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			c := &Encoder{
 				data: tt.fields.data,
 			}
-			if err := c.WriteRequest(tt.args.path, tt.args.tag); (err != nil) != tt.wantErr {
+			if err := c.WriteRequest(tt.args.path, tt.args.tag, tt.args.cmd); (err != nil) != tt.wantErr {
 				t.Fatalf("Encoder.WriteRequest() error = %v, wantErr %v", err, tt.wantErr)
 			}
 
@@ -308,15 +322,21 @@ func TestEncoder_WriteGetDirCommand(t *testing.T) {
 		data *bytes.Buffer
 	}
 
+	type args struct {
+		cmd int
+	}
+
 	tests := []struct {
 		name    string
 		fields  fields
+		args    args
 		want    []byte
 		wantErr bool
 	}{
 		{
 			"+valid",
 			fields{bytes.NewBuffer([]byte{})},
+			args{EmberGetDirCommand},
 			[]byte{
 				0xa0, 0x80, 0x62, 0x80, 0xA0, 0x03, 0x02, 0x01, 0x20, 0xA1, 0x03, 0x02, 0x01,
 				0xFF, 0x00, 0x00, 0x00, 0x00,
@@ -326,6 +346,7 @@ func TestEncoder_WriteGetDirCommand(t *testing.T) {
 		{
 			"+existingData",
 			fields{bytes.NewBuffer([]byte{0x00, 0x00})},
+			args{EmberGetDirCommand},
 			[]byte{
 				0x00, 0x00, 0xa0, 0x80, 0x62, 0x80, 0xA0, 0x03, 0x02, 0x01, 0x20, 0xA1, 0x03, 0x02, 0x01,
 				0xFF, 0x00, 0x00, 0x00, 0x00,
@@ -342,7 +363,7 @@ func TestEncoder_WriteGetDirCommand(t *testing.T) {
 			c := &Encoder{
 				data: tt.fields.data,
 			}
-			if err := c.WriteGetDirCommand(); (err != nil) != tt.wantErr {
+			if err := c.WriteCommand(tt.args.cmd); (err != nil) != tt.wantErr {
 				t.Fatalf("Encoder.WriteGetDirCommand() error = %v, wantErr %v", err, tt.wantErr)
 			}
 
